@@ -6,4 +6,5 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
 # obtain one at http://mozilla.org/MPL/2.0/.
 
-from .schema import ModelSchema, RegistryNotFound  # noqa
+from .schema import ModelSchema  # noqa
+from .exceptions import RegistryNotFound  # noqa
